\name{get.ids}
\alias{get.ids}
\title{
Obtains a set of gene identifiers
}
\description{
Obtains a set of gene identifiers that fulfill one or more of the criteria pass in the input.
}
\usage{
get.ids(descr = NULL, ExistInAll = NULL, isTF = NULL)
}
\arguments{
  \item{descr}{
One or more words (character strings) that must be present in the \code{Prot.Desc} of the \code{gene} \code{data.frame} to be presented in the output of the function.
}
  \item{ExistInAll}{
A \code{logical} variable; if \code{TRUE} only genes that were expressed in all 12 accessions will be present in the output.
}
  \item{isTF}{
A \code{logical} variable; if \code{TRUE} only genes that are annotated as Transcription Factors will be present in the output.
}
}
\details{
One or more of the criteria in the input must be not \code{NULL}, otherwise the function will produce an error.
}
\value{
Either \code{NULL}, when no gene fulfills all criteria pass in the input, or a \code{integer} vector including all gene idendifiers of the genes that fulfill all criteria pass to the function in the input.
}
\references{
Escoto-Sandoval C, Flores-Diaz A, Reyes-Valdes MH, Ochoa-Alejo N and Martinez O. "Salsa: An R database to analyze gene expression profiles in chili pepper fruit". (Submitted, 2021).

Martinez O, et al. "Transcriptome Analyses Throughout Chili Pepper Fruit Development Reveal Novel Insights into the Domestication Process". Plants. 2021; 10(3):585. doi.org/10.3390/plants10030585
}
\author{
O. Martinez
}
\seealso{
\code{\link{gene}}, \code{\link{get.genes.by.desc}}, \code{\link{browse.gene}}. 
}
\examples{
# Returns NULL
# (because descr is not found in
# any gene description)
get.ids(descr="My favorite gene")

# Returns the ids of all genes expressed
# in the 12 accessions
# get.ids(ExistInAll=TRUE)
# See the first 6 of them
head(get.ids(ExistInAll=TRUE))
# How many?
length(get.ids(ExistInAll=TRUE))

# How many genes are annotated as
# Transcription Factors?
length(get.ids(isTF=TRUE))

# And how many of those include in
# the description the character 
# strings "WRKY"
length(get.ids(descr="WRKY"))

# See some of the Prot.Desc of those genes
gene$Prot.Desc[is.element(gene$id, tail(get.ids(descr="WRKY")))]

# Example using multiple criteria
# of selection
get.ids(descr=c("zipper", "HAT"), ExistInAll=TRUE, isTF=TRUE)
}
