\name{library.desc}
\alias{library.desc}
\docType{data}
\title{
Library description
}
\description{
A data frame with variables describing the RNA-Seq libraries deposited in the NCBI GEO database (GEO accession number GSE165448). 
}
\usage{data("library.desc")}
\format{
  A data frame with 179 observations on the following 8 variables.
  \describe{
    \item{\code{name}}{a character vector; a six characters coding the name of the library.}
    \item{\code{GEO.sample}}{a character vector; sample name of the library at GEO.}
    \item{\code{acc.key}}{a character vector; two characters code for accession name.}
    \item{\code{tissue}}{a character vector; source of tissue for the library: fruit or plantlet.}
    \item{\code{time}}{a numeric vector; time of development in DAA.}
    \item{\code{replicate}}{a numeric vector; number of biological replicate (1 or 2).}
    \item{\code{in.Salsa}}{a logical vector; Are the data from this library used in Salsa?}
    \item{\code{acc.type}}{a character vector; type of accession: D - Domesticated, W- Wild, C - Cross.}
  }
}
\details{
This data frame give details of all 179 libraries, the majority of which were used to obtain the curated data that are in Salsa.
}
\source{
Cinvestav Irapuato, Mexico. All libraries were deposited in GEO accession GSE165448 (see https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE165448)
}
\references{
Escoto-Sandoval C, Flores-Diaz A, Reyes-Valdes MH, Ochoa-Alejo N and Martinez O. "Salsa: An R database to analyze gene expression profiles in chili pepper fruit". (Submitted, 2021).

Martinez O, et al. "Transcriptome Analyses Throughout Chili Pepper Fruit Development Reveal Novel Insights into the Domestication Process". Plants. 2021; 10(3):585. doi.org/10.3390/plants10030585
}
\examples{
data(library.desc)
head(library.desc)
# Tabulate the number of libraries per accession
table(library.desc$acc.key)
# Gives the number of libraries used in Salsa
table(library.desc$in.Salsa)
}
\keyword{datasets}
